"""
web2ldap plugin classes for OpenLDAP

$Id: openldap.py,v 1.10 2008/01/16 17:31:55 michael Exp $
"""

from w2lapp.schema.syntaxes import DistinguishedName,DirectoryString,Uri,syntax_registry

import ldap.filter
import w2lapp.gui

class EntryCSN(DirectoryString):
  oid = '1.3.6.1.4.1.4203.666.1.7'
  desc = 'OpenLDAP EntryCSN'


class AuditContext(DistinguishedName):
  oid = 'AuditContext'
  desc = 'OpenLDAP DN pointing to audit naming context'

  def displayValue(self,valueindex=0,commandbutton=0):
    r = [DistinguishedName.displayValue(self,valueindex,commandbutton)]
    if commandbutton:
      r.extend([
	self._form.applAnchor(
	  'search','Audit trail',self._sid,
          [
            ('dn',self.attrValue),
            ('search_filterstr','(&(objectClass=auditObject)(reqDN=%s))' % (ldap.filter.escape_filter_chars(self._dn))),
            ('scope',str(ldap.SCOPE_ONELEVEL)),
          ],
          title='Complete audit trail for current entry',
	),
	self._form.applAnchor(
	  'search','Write audit trail',self._sid,
          [
            ('dn',self.attrValue),
            ('search_filterstr','(&(objectClass=auditWriteObject)(reqDN=%s))' % (ldap.filter.escape_filter_chars(self._dn))),
            ('scope',str(ldap.SCOPE_ONELEVEL)),
          ],
          title='Audit trail of write access to current entry',
	),
      ])
    return ' | '.join(r)

syntax_registry.registerAttrType(
  AuditContext.oid,['1.3.6.1.4.1.4203.666.11.5.1.30','auditContext'] # auditContext
)


# Register all syntax classes in this module
for symbol_name in dir():
  syntax_registry.registerSyntaxClass(eval(symbol_name))

syntax_registry.registerAttrType(
  DistinguishedName.oid,[
    'entryDN','monitorConnectionAuthzDN',
    'configContext','monitorContext','reqDN','reqAuthzID'
  ]
)

syntax_registry.registerAttrType(
  Uri.oid,['monitorConnectionListener']
)

